//  ************************************************************************************************
//
//  BornAgain: simulate and fit reflection and scattering
//
//! @file      GUI/Model/Descriptor/AxisProperty.cpp
//! @brief     Implements class AxisProperty
//!
//! @homepage  http://www.bornagainproject.org
//! @license   GNU General Public License v3 or higher (see COPYING)
//! @copyright Forschungszentrum Jülich GmbH 2022
//! @authors   Scientific Computing Group at MLZ (see CITATION, AUTHORS)
//
//  ************************************************************************************************

#include "GUI/Model/Descriptor/AxisProperty.h"
#include "Base/Util/Assert.h"
#include "GUI/Support/XML/Serialize.h"

using std::variant;

AxisProperty::AxisProperty()
    : m_nbins(100)
{
}

void AxisProperty::initMin(const QString& label, const QString& tooltip, double value,
                           const variant<QString, Unit>& unit, const RealLimits& limits,
                           uint decimals)
{
    m_min.init(label, tooltip, value, unit, decimals, limits, "min");
}

void AxisProperty::initMax(const QString& label, const QString& tooltip, double value,
                           const variant<QString, Unit>& unit, const RealLimits& limits,
                           uint decimals)
{
    m_max.init(label, tooltip, value, unit, decimals, limits, "max");
}

std::unique_ptr<FixedBinAxis> AxisProperty::createAxis(double scaleFactor) const
{
    return std::make_unique<FixedBinAxis>(std::string(), m_nbins, m_min * scaleFactor,
                                          m_max * scaleFactor);
}

void AxisProperty::rwAxisProperty(Streamer& s, const QString& tag)
{
    s.start(tag);
    s.assertVersion(0);
    Serialize::rwValue(s, "nbins", m_nbins);
    Serialize::rwProperty(s, m_min);
    Serialize::rwProperty(s, m_max);
    s.finish(tag);
}

uint AxisProperty::nbins() const
{
    return m_nbins;
}

void AxisProperty::setNbins(uint value)
{
    m_nbins = value;
}
